==> arquillian-container-test-impl-base-1.1.9.Final-sources.jar: org/jboss/arquillian/container/test/impl/execution/BeforeLifecycleEventExecuter.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl.execution;

import org.jboss.arquillian.core.api.annotation.Observes;
import org.jboss.arquillian.test.spi.event.suite.BeforeTestLifecycleEvent;

/**
 * Observer that executes the Before phase on the test case.
 * 
 * This is intended for In Container use, BeforeClass should only be executed on Client since the state between @Test is not kept In Container.
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 * @see AfterLifecycleEventExecuter
 */
public class BeforeLifecycleEventExecuter
{
   public void on(@Observes(precedence = -100) BeforeTestLifecycleEvent event) throws Throwable
   {
      event.getExecutor().invoke();
   }
}

==> arquillian-container-test-impl-base-1.4.0.Final-sources.jar: org/jboss/arquillian/container/test/impl/execution/BeforeLifecycleEventExecuter.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl.execution;

import org.jboss.arquillian.core.api.annotation.Observes;
import org.jboss.arquillian.test.spi.event.suite.BeforeTestLifecycleEvent;

/**
 * Observer that executes the Before phase on the test case.
 * <p>
 * This is intended for In Container use, BeforeClass should only be executed on Client since the state between @Test is
 * not kept In Container.
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 * @see AfterLifecycleEventExecuter
 */
public class BeforeLifecycleEventExecuter {
    public void on(@Observes(precedence = -100) BeforeTestLifecycleEvent event) throws Throwable {
        event.getExecutor().invoke();
    }
}
